Index: /trunk/src/org/openstreetmap/josm/data/osm/Way.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/data/osm/Way.java	(revision 1933)
+++ /trunk/src/org/openstreetmap/josm/data/osm/Way.java	(revision 1934)
@@ -55,6 +55,7 @@
 
     /**
-     *
-     * @return
+     * Replies the number of nodes in this ways.
+     * 
+     * @return the number of nodes in this ways.
      * @since 1862
      */
@@ -64,7 +65,10 @@
 
     /**
-     *
-     * @param index
-     * @return
+     * Replies the node at position <code>index</code>.
+     * 
+     * @param index the position
+     * @return  the node at position <code>index</code>
+     * @exception IndexOutOfBoundsException thrown if <code>index</code> < 0
+     * or <code>index</code> >= {@see #getNodesCount()}
      * @since 1862
      */
@@ -129,8 +133,10 @@
 
     /**
-     * Create an identical clone of the argument (including the id)
-     */
-    public Way(Way clone) {
-        cloneFrom(clone);
+     * Create an identical clone of the argument (including the id).
+     * 
+     * @param original  the original way. Must not be null.
+     */
+    public Way(Way original) {
+        cloneFrom(original);
     }
 
@@ -143,7 +149,11 @@
 
     /**
-     * Create an incomplete Way.
+     * Create an incomplete Way with a given id.
+     * 
+     * @param id  the id. id > 0 required.
      */
     public Way(long id) {
+        // FIXME: shouldn't we check for id > 0?
+        //
         this.id = id;
         incomplete = true;
